==> openshift-model-config-7.1.0-sources.jar: io/fabric8/openshift/api/model/config/v1/TestReportingSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TestReportingSpecFluent<A extends TestReportingSpecFluent<A>> extends BaseFluent<A>{
  public TestReportingSpecFluent() {
  }
  
  public TestReportingSpecFluent(TestReportingSpec instance) {
    this.copyInstance(instance);
  }
  private ArrayList<FeatureGateTestsBuilder> testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(TestReportingSpec instance) {
    instance = (instance != null ? instance : new TestReportingSpec());
    if (instance != null) {
          this.withTestsForFeatureGates(instance.getTestsForFeatureGates());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToTestsForFeatureGates(int index,FeatureGateTests item) {
    if (this.testsForFeatureGates == null) {this.testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();}
    FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);
    if (index < 0 || index >= testsForFeatureGates.size()) { _visitables.get("testsForFeatureGates").add(builder); testsForFeatureGates.add(builder); } else { _visitables.get("testsForFeatureGates").add(index, builder); testsForFeatureGates.add(index, builder);}
    return (A)this;
  }
  
  public A setToTestsForFeatureGates(int index,FeatureGateTests item) {
    if (this.testsForFeatureGates == null) {this.testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();}
    FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);
    if (index < 0 || index >= testsForFeatureGates.size()) { _visitables.get("testsForFeatureGates").add(builder); testsForFeatureGates.add(builder); } else { _visitables.get("testsForFeatureGates").set(index, builder); testsForFeatureGates.set(index, builder);}
    return (A)this;
  }
  
  public A addToTestsForFeatureGates(io.fabric8.openshift.api.model.config.v1.FeatureGateTests... items) {
    if (this.testsForFeatureGates == null) {this.testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();}
    for (FeatureGateTests item : items) {FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);_visitables.get("testsForFeatureGates").add(builder);this.testsForFeatureGates.add(builder);} return (A)this;
  }
  
  public A addAllToTestsForFeatureGates(Collection<FeatureGateTests> items) {
    if (this.testsForFeatureGates == null) {this.testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();}
    for (FeatureGateTests item : items) {FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);_visitables.get("testsForFeatureGates").add(builder);this.testsForFeatureGates.add(builder);} return (A)this;
  }
  
  public A removeFromTestsForFeatureGates(io.fabric8.openshift.api.model.config.v1.FeatureGateTests... items) {
    if (this.testsForFeatureGates == null) return (A)this;
    for (FeatureGateTests item : items) {FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);_visitables.get("testsForFeatureGates").remove(builder); this.testsForFeatureGates.remove(builder);} return (A)this;
  }
  
  public A removeAllFromTestsForFeatureGates(Collection<FeatureGateTests> items) {
    if (this.testsForFeatureGates == null) return (A)this;
    for (FeatureGateTests item : items) {FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);_visitables.get("testsForFeatureGates").remove(builder); this.testsForFeatureGates.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromTestsForFeatureGates(Predicate<FeatureGateTestsBuilder> predicate) {
    if (testsForFeatureGates == null) return (A) this;
    final Iterator<FeatureGateTestsBuilder> each = testsForFeatureGates.iterator();
    final List visitables = _visitables.get("testsForFeatureGates");
    while (each.hasNext()) {
      FeatureGateTestsBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<FeatureGateTests> buildTestsForFeatureGates() {
    return this.testsForFeatureGates != null ? build(testsForFeatureGates) : null;
  }
  
  public FeatureGateTests buildTestsForFeatureGate(int index) {
    return this.testsForFeatureGates.get(index).build();
  }
  
  public FeatureGateTests buildFirstTestsForFeatureGate() {
    return this.testsForFeatureGates.get(0).build();
  }
  
  public FeatureGateTests buildLastTestsForFeatureGate() {
    return this.testsForFeatureGates.get(testsForFeatureGates.size() - 1).build();
  }
  
  public FeatureGateTests buildMatchingTestsForFeatureGate(Predicate<FeatureGateTestsBuilder> predicate) {
      for (FeatureGateTestsBuilder item : testsForFeatureGates) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingTestsForFeatureGate(Predicate<FeatureGateTestsBuilder> predicate) {
      for (FeatureGateTestsBuilder item : testsForFeatureGates) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withTestsForFeatureGates(List<FeatureGateTests> testsForFeatureGates) {
    if (this.testsForFeatureGates != null) {
      this._visitables.get("testsForFeatureGates").clear();
    }
    if (testsForFeatureGates != null) {
        this.testsForFeatureGates = new ArrayList();
        for (FeatureGateTests item : testsForFeatureGates) {
          this.addToTestsForFeatureGates(item);
        }
    } else {
      this.testsForFeatureGates = null;
    }
    return (A) this;
  }
  
  public A withTestsForFeatureGates(io.fabric8.openshift.api.model.config.v1.FeatureGateTests... testsForFeatureGates) {
    if (this.testsForFeatureGates != null) {
        this.testsForFeatureGates.clear();
        _visitables.remove("testsForFeatureGates");
    }
    if (testsForFeatureGates != null) {
      for (FeatureGateTests item : testsForFeatureGates) {
        this.addToTestsForFeatureGates(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasTestsForFeatureGates() {
    return this.testsForFeatureGates != null && !this.testsForFeatureGates.isEmpty();
  }
  
  public TestsForFeatureGatesNested<A> addNewTestsForFeatureGate() {
    return new TestsForFeatureGatesNested(-1, null);
  }
  
  public TestsForFeatureGatesNested<A> addNewTestsForFeatureGateLike(FeatureGateTests item) {
    return new TestsForFeatureGatesNested(-1, item);
  }
  
  public TestsForFeatureGatesNested<A> setNewTestsForFeatureGateLike(int index,FeatureGateTests item) {
    return new TestsForFeatureGatesNested(index, item);
  }
  
  public TestsForFeatureGatesNested<A> editTestsForFeatureGate(int index) {
    if (testsForFeatureGates.size() <= index) throw new RuntimeException("Can't edit testsForFeatureGates. Index exceeds size.");
    return setNewTestsForFeatureGateLike(index, buildTestsForFeatureGate(index));
  }
  
  public TestsForFeatureGatesNested<A> editFirstTestsForFeatureGate() {
    if (testsForFeatureGates.size() == 0) throw new RuntimeException("Can't edit first testsForFeatureGates. The list is empty.");
    return setNewTestsForFeatureGateLike(0, buildTestsForFeatureGate(0));
  }
  
  public TestsForFeatureGatesNested<A> editLastTestsForFeatureGate() {
    int index = testsForFeatureGates.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last testsForFeatureGates. The list is empty.");
    return setNewTestsForFeatureGateLike(index, buildTestsForFeatureGate(index));
  }
  
  public TestsForFeatureGatesNested<A> editMatchingTestsForFeatureGate(Predicate<FeatureGateTestsBuilder> predicate) {
    int index = -1;
    for (int i=0;i<testsForFeatureGates.size();i++) { 
    if (predicate.test(testsForFeatureGates.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching testsForFeatureGates. No match found.");
    return setNewTestsForFeatureGateLike(index, buildTestsForFeatureGate(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TestReportingSpecFluent that = (TestReportingSpecFluent) o;
    if (!java.util.Objects.equals(testsForFeatureGates, that.testsForFeatureGates)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(testsForFeatureGates,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (testsForFeatureGates != null && !testsForFeatureGates.isEmpty()) { sb.append("testsForFeatureGates:"); sb.append(testsForFeatureGates + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class TestsForFeatureGatesNested<N> extends FeatureGateTestsFluent<TestsForFeatureGatesNested<N>> implements Nested<N>{
    TestsForFeatureGatesNested(int index,FeatureGateTests item) {
      this.index = index;
      this.builder = new FeatureGateTestsBuilder(this, item);
    }
    FeatureGateTestsBuilder builder;
    int index;
    
    public N and() {
      return (N) TestReportingSpecFluent.this.setToTestsForFeatureGates(index,builder.build());
    }
    
    public N endTestsForFeatureGate() {
      return and();
    }
    
  
  }

}

==> openshift-model-config-7.4.0-sources.jar: io/fabric8/openshift/api/model/config/v1/TestReportingSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TestReportingSpecFluent<A extends TestReportingSpecFluent<A>> extends BaseFluent<A>{
  public TestReportingSpecFluent() {
  }
  
  public TestReportingSpecFluent(TestReportingSpec instance) {
    this.copyInstance(instance);
  }
  private ArrayList<FeatureGateTestsBuilder> testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(TestReportingSpec instance) {
    instance = (instance != null ? instance : new TestReportingSpec());
    if (instance != null) {
          this.withTestsForFeatureGates(instance.getTestsForFeatureGates());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToTestsForFeatureGates(int index,FeatureGateTests item) {
    if (this.testsForFeatureGates == null) {this.testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();}
    FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);
    if (index < 0 || index >= testsForFeatureGates.size()) {
        _visitables.get("testsForFeatureGates").add(builder);
        testsForFeatureGates.add(builder);
    } else {
        _visitables.get("testsForFeatureGates").add(builder);
        testsForFeatureGates.add(index, builder);
    }
    return (A)this;
  }
  
  public A setToTestsForFeatureGates(int index,FeatureGateTests item) {
    if (this.testsForFeatureGates == null) {this.testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();}
    FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);
    if (index < 0 || index >= testsForFeatureGates.size()) {
        _visitables.get("testsForFeatureGates").add(builder);
        testsForFeatureGates.add(builder);
    } else {
        _visitables.get("testsForFeatureGates").add(builder);
        testsForFeatureGates.set(index, builder);
    }
    return (A)this;
  }
  
  public A addToTestsForFeatureGates(io.fabric8.openshift.api.model.config.v1.FeatureGateTests... items) {
    if (this.testsForFeatureGates == null) {this.testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();}
    for (FeatureGateTests item : items) {FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);_visitables.get("testsForFeatureGates").add(builder);this.testsForFeatureGates.add(builder);} return (A)this;
  }
  
  public A addAllToTestsForFeatureGates(Collection<FeatureGateTests> items) {
    if (this.testsForFeatureGates == null) {this.testsForFeatureGates = new ArrayList<FeatureGateTestsBuilder>();}
    for (FeatureGateTests item : items) {FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);_visitables.get("testsForFeatureGates").add(builder);this.testsForFeatureGates.add(builder);} return (A)this;
  }
  
  public A removeFromTestsForFeatureGates(io.fabric8.openshift.api.model.config.v1.FeatureGateTests... items) {
    if (this.testsForFeatureGates == null) return (A)this;
    for (FeatureGateTests item : items) {FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);_visitables.get("testsForFeatureGates").remove(builder); this.testsForFeatureGates.remove(builder);} return (A)this;
  }
  
  public A removeAllFromTestsForFeatureGates(Collection<FeatureGateTests> items) {
    if (this.testsForFeatureGates == null) return (A)this;
    for (FeatureGateTests item : items) {FeatureGateTestsBuilder builder = new FeatureGateTestsBuilder(item);_visitables.get("testsForFeatureGates").remove(builder); this.testsForFeatureGates.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromTestsForFeatureGates(Predicate<FeatureGateTestsBuilder> predicate) {
    if (testsForFeatureGates == null) return (A) this;
    final Iterator<FeatureGateTestsBuilder> each = testsForFeatureGates.iterator();
    final List visitables = _visitables.get("testsForFeatureGates");
    while (each.hasNext()) {
      FeatureGateTestsBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<FeatureGateTests> buildTestsForFeatureGates() {
    return this.testsForFeatureGates != null ? build(testsForFeatureGates) : null;
  }
  
  public FeatureGateTests buildTestsForFeatureGate(int index) {
    return this.testsForFeatureGates.get(index).build();
  }
  
  public FeatureGateTests buildFirstTestsForFeatureGate() {
    return this.testsForFeatureGates.get(0).build();
  }
  
  public FeatureGateTests buildLastTestsForFeatureGate() {
    return this.testsForFeatureGates.get(testsForFeatureGates.size() - 1).build();
  }
  
  public FeatureGateTests buildMatchingTestsForFeatureGate(Predicate<FeatureGateTestsBuilder> predicate) {
      for (FeatureGateTestsBuilder item : testsForFeatureGates) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingTestsForFeatureGate(Predicate<FeatureGateTestsBuilder> predicate) {
      for (FeatureGateTestsBuilder item : testsForFeatureGates) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withTestsForFeatureGates(List<FeatureGateTests> testsForFeatureGates) {
    if (this.testsForFeatureGates != null) {
      this._visitables.get("testsForFeatureGates").clear();
    }
    if (testsForFeatureGates != null) {
        this.testsForFeatureGates = new ArrayList();
        for (FeatureGateTests item : testsForFeatureGates) {
          this.addToTestsForFeatureGates(item);
        }
    } else {
      this.testsForFeatureGates = null;
    }
    return (A) this;
  }
  
  public A withTestsForFeatureGates(io.fabric8.openshift.api.model.config.v1.FeatureGateTests... testsForFeatureGates) {
    if (this.testsForFeatureGates != null) {
        this.testsForFeatureGates.clear();
        _visitables.remove("testsForFeatureGates");
    }
    if (testsForFeatureGates != null) {
      for (FeatureGateTests item : testsForFeatureGates) {
        this.addToTestsForFeatureGates(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasTestsForFeatureGates() {
    return this.testsForFeatureGates != null && !this.testsForFeatureGates.isEmpty();
  }
  
  public TestsForFeatureGatesNested<A> addNewTestsForFeatureGate() {
    return new TestsForFeatureGatesNested(-1, null);
  }
  
  public TestsForFeatureGatesNested<A> addNewTestsForFeatureGateLike(FeatureGateTests item) {
    return new TestsForFeatureGatesNested(-1, item);
  }
  
  public TestsForFeatureGatesNested<A> setNewTestsForFeatureGateLike(int index,FeatureGateTests item) {
    return new TestsForFeatureGatesNested(index, item);
  }
  
  public TestsForFeatureGatesNested<A> editTestsForFeatureGate(int index) {
    if (testsForFeatureGates.size() <= index) throw new RuntimeException("Can't edit testsForFeatureGates. Index exceeds size.");
    return setNewTestsForFeatureGateLike(index, buildTestsForFeatureGate(index));
  }
  
  public TestsForFeatureGatesNested<A> editFirstTestsForFeatureGate() {
    if (testsForFeatureGates.size() == 0) throw new RuntimeException("Can't edit first testsForFeatureGates. The list is empty.");
    return setNewTestsForFeatureGateLike(0, buildTestsForFeatureGate(0));
  }
  
  public TestsForFeatureGatesNested<A> editLastTestsForFeatureGate() {
    int index = testsForFeatureGates.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last testsForFeatureGates. The list is empty.");
    return setNewTestsForFeatureGateLike(index, buildTestsForFeatureGate(index));
  }
  
  public TestsForFeatureGatesNested<A> editMatchingTestsForFeatureGate(Predicate<FeatureGateTestsBuilder> predicate) {
    int index = -1;
    for (int i=0;i<testsForFeatureGates.size();i++) { 
    if (predicate.test(testsForFeatureGates.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching testsForFeatureGates. No match found.");
    return setNewTestsForFeatureGateLike(index, buildTestsForFeatureGate(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TestReportingSpecFluent that = (TestReportingSpecFluent) o;
    if (!java.util.Objects.equals(testsForFeatureGates, that.testsForFeatureGates)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(testsForFeatureGates,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (testsForFeatureGates != null && !testsForFeatureGates.isEmpty()) { sb.append("testsForFeatureGates:"); sb.append(testsForFeatureGates + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class TestsForFeatureGatesNested<N> extends FeatureGateTestsFluent<TestsForFeatureGatesNested<N>> implements Nested<N>{
    TestsForFeatureGatesNested(int index,FeatureGateTests item) {
      this.index = index;
      this.builder = new FeatureGateTestsBuilder(this, item);
    }
    FeatureGateTestsBuilder builder;
    int index;
    
    public N and() {
      return (N) TestReportingSpecFluent.this.setToTestsForFeatureGates(index,builder.build());
    }
    
    public N endTestsForFeatureGate() {
      return and();
    }
    
  
  }

}
